workflow_transition
open | /ksstestportal/kssfolder/newsitem |
waitForElementPresent | //dl[@id='plone-contentmenu-workflow']//a/span[@class='state-private'] |
assertTextPresent | State: Private |
click | //dl[@id='plone-contentmenu-workflow']/dt/a/span[@class='state-private'] |
waitForElementPresent | workflow-transition-publish |
click | //a[@id='workflow-transition-publish']/span |
waitForVisible | kssPortalMessage |
assertTextPresent | Item state changed |
assertTextPresent | State: Published |
click | //dl[@id='plone-contentmenu-workflow']/dt/a/span[@class='state-published'] |
waitForElementPresent | workflow-transition-reject |
click | //a[@id='workflow-transition-reject']/span |
waitForVisible | kssPortalMessage |
assertTextPresent | Item state changed |
assertTextPresent | State: Private |